OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Контакти",
    "Address book name" : "Име на адреснакнига ",
    "Import" : "Внасяне",
    "No contacts in here" : "Тук няма контакти",
    "Name" : "Име",
    "Organization" : "Организация",
    "Title" : "Заглавие",
    "Add field ..." : "Добави приятел",
    "No search result for {query}" : "Няма намерени резултати за {query}",
    "Postal code" : "Пощенски код",
    "City" : "Град",
    "State or province" : "Страна или област",
    "Country" : "Държава",
    "Address" : "Адрес",
    "(new group)" : "(нова група)",
    "Last name" : "Последно име",
    "First name" : "Първо Име",
    "Additional names" : "Други имена",
    "All contacts" : "Всички контакти",
    "Not grouped" : "Негрупирани",
    "New contact" : "Нов контакт",
    "{addressbook} shared by {owner}" : "{addressbook} споделена с {owner}",
    "No contacts in file. Only VCard files are allowed." : "Няма контакти в файла. Само VCard файлове са разрешени.",
    "Nickname" : "Псевдоним",
    "Notes" : "Бележки",
    "Website" : "Интернет Страница",
    "Home" : "Домашен",
    "Work" : "Работно",
    "Other" : "Друга...",
    "Groups" : "Групи",
    "Birthday" : "Рожден ден",
    "Email" : "Имейл",
    "Instant messaging" : "Чат",
    "Phone" : "Телефон",
    "Mobile" : "Мобилен",
    "Fax" : "Факс",
    "Fax home" : "Факс домашен",
    "Fax work" : "Факс служебен",
    "Pager" : "Пейджър",
    "Voice" : "Гласов",
    "Settings" : "Настройки"
},
"nplurals=2; plural=(n != 1);");
